REST_API_URL = "https://rest-api.wm.com/"

API_KEY_PAYMENT= "6ACAFBEEC54039F21716"
API_KEY_ROLLOFF= "5B1B5D23674B426465F0"
API_KEY_REPAIR= "6277FF29BB19666078AC"
API_KEY_AUTHENTICATION= "6277FF29BB19666078AC"
API_KEY_BALANCE_INVOICE= "615F2EFC82FF8BB2F864"
API_KEY_CUSTOMER_SERVICES= "1611D2AB8045EFB4D148"
API_KEY_USER_ACCOUNTS= "AABFF96D4542575160FC"
API_KEY_USER_REQUEST_SERVICE= "F1ADA754F65E546BFC97"
API_KEY_CHAT_LOGGED_IN= "2DC6C5B8146A1C281F96"
API_KEY_CHAT_LOGGED_IN_MOBILE= "306B8BA80546A3CE5DEC"
API_KEY_APPLE_PAY= "B8F7CE5A093141B1FFA2"
API_KEY_APPLE_PAY_SCHEDULED= "4E6D3BBDE553BE2807ED"
API_KEY_APPLE_PAY_AUTOPAY= "6CBA95B0A31A94C3C91C"
API_KEY_APPLE_PAY_PROCESS= "0A4031783CB69A4BC435"
API_KEY_BULK_AUTOPAY_PAPERLESS_ENROLL= "65D55CF6F9D38F50E02C"
API_KEY_SERVICE_CHANGE= "74DC8D4A7C565E51908E"
API_KEY_PAUSE_SERVICE= "74DC8D4A7C565E51908E"
API_KEY_ALERTS= "C861FBA520CDD18ADC8D"
API_KEY_INCIDENTS_BY_USER_ID= "6277FF29BB19666078AC"
API_KEY_EXTRA_PICKUP= "615F2EFC82FF8BB2F864"
API_KEY_BULK_PICKUP= "6277FF29BB19666078AC"
API_KEY_RECYCLING_PICKUP= "615F2EFC82FF8BB2F864" 
API_KEY_HISTORY_VISUALS= "615F2EFC82FF8BB2F864"
API_KEY_PENDING_CHARGES= "615F2EFC82FF8BB2F864"
API_KEY_COMBINED_ORDER_HISTORY= "6277FF29BB19666078AC"
API_KEY_SURVEY= "6277FF29BB19666078AC"
API_KEY_HOLIDAYS_USER_BY_CUSTOMER_ID= "6277FF29BB19666078AC"
API_KEY_HOLIDAYS_USER_BY_ADDRESS= "6277FF29BB19666078AC"
API_KEY_CONTACT_INFO_USER_BY_CUSTOMER_ID= "6277FF29BB19666078AC"
API_KEY_CONTACT_INFO_USER_BY_ADDRESS= "6277FF29BB19666078AC"
API_KEY_USER_BILLING_DETAILS= "6277FF29BB19666078AC"
API_KEY_PAPERLESS_PREFERENCES= "6277FF29BB19666078AC"
API_KEY_TEXT_FOR_BULK= "65D55CF6F9D38F50E02C"
API_KEY_TEXT_FOR_ROLLOFF= "65D55CF6F9D38F50E02C"
API_KEY_TEXT_FOR_XPU= "65D55CF6F9D38F50E02C"
API_KEY_TEXT_FOR_CONTAINER_REPAIR= "65D55CF6F9D38F50E02C"
API_KEY_REPORT_MISSED_PICKUP= "6277FF29BB19666078AC"
API_KEY_TEXT_FOR_CITY_BILLED_BULK= "65D55CF6F9D38F50E02C"
API_KEY_REFRESH_TOKEN= "0zqoBUUwHpGwp04xxkwM5zKBCy8SeLYm9BibvwEgN2g"
API_KEY_ORDERS= "E5E2902D4E578F37CNQ3"